// © 2023 John Breaux
//! The definition of a label
use super::*;

/// The definition of a label
#[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
pub struct Label(pub Identifier);

impl Parsable for Label {
    fn parse<'text, T>(p: &Parser, stream: &mut T) -> Result<Self, ParseError>
    where T: TokenStream<'text> {
        Ok(Self(Identifier::parse(p, stream).and_then(|t| {
            stream.require(Type::Label)?;
            Ok(t)
        })?))
    }
}

impl Display for Label {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result { write!(f, "{}:", self.0) }
}
